@@ -19,11 +19,11 @@
 #define _BlockNameIO_incl_
 
 #include "NameIO.h"
+#include "CipherKey.h"
 
-#include "Ptr.h"
+#include <boost/shared_ptr.hpp>
 
 class Cipher;
-typedef rel::OpaqueValue CipherKey;
 
 /*
     Implement NameIO interface for filename encoding.  Uses cipher in block
@@ -36,7 +36,7 @@ public:
     static rel::Interface CurrentInterface();
 
     BlockNameIO( const rel::Interface &iface,
-	         const rel::Ptr<Cipher> &cipher, 
+	         const boost::shared_ptr<Cipher> &cipher, 
 	         const CipherKey &key, int blockSize );
     virtual ~BlockNameIO();
 
@@ -45,17 +45,18 @@ public:
     virtual int maxEncodedNameLen( int plaintextNameLen ) const;
     virtual int maxDecodedNameLen( int encodedNameLen ) const;
 
+    // hack to help with static builds
+    static bool Enabled();
+protected:
     virtual int encodeName( const char *plaintextName, int length,
 	                    uint64_t *iv, char *encodedName ) const;
     virtual int decodeName( const char *encodedName, int length,
 	                    uint64_t *iv, char *plaintextName ) const;
 
-    // hack to help with static builds
-    static bool Enabled();
 private:
     int _interface;
     int _bs;
-    rel::Ptr<Cipher> _cipher;
+    boost::shared_ptr<Cipher> _cipher;
     CipherKey _key;
 };
 
