@@ -23,10 +23,6 @@
 #include <inttypes.h>
 
 #include "Interface.h"
-#include "Config.h"
-#include "Ptr.h"
-
-using rel::Ptr;
 
 struct IORequest
 {
