@@ -1356,9 +1356,7 @@ shared_ptr<Cipher> EncFSConfig::getCipher() const
 
 void EncFSConfig::assignKeyData(const std::string &in)
 {
-    keyData.resize(in.length());
-    for(unsigned int i=0; i<in.length(); ++i)
-        keyData[i] = in.data()[i];
+    keyData.assign(in.data(), in.data()+in.length());
 }
 
 void EncFSConfig::assignKeyData(unsigned char *data, int len)
@@ -1664,7 +1662,7 @@ RootPtr initFS( EncFS_Context *ctx, const shared_ptr<EncFS_Opts> &opts )
         fsConfig->nameCoding = nameCoder;
         fsConfig->config = config;
         fsConfig->forceDecode = opts->forceDecode;
-        fsConfig->reverseEncryption = opts->forceDecode;
+        fsConfig->reverseEncryption = opts->reverseEncryption;
         fsConfig->opts = opts;
 
 	rootInfo = RootPtr( new EncFS_Root );
