@@ -23,7 +23,10 @@
 class NullNameIO : public NameIO
 {
 public:
+    static rel::Interface CurrentInterface();
+
     NullNameIO( );
+
     virtual ~NullNameIO();
 
     virtual rel::Interface interface() const;
@@ -31,13 +34,13 @@ public:
     virtual int maxEncodedNameLen( int plaintextNameLen ) const;
     virtual int maxDecodedNameLen( int encodedNameLen ) const;
 
+   // hack to help with static builds
+    static bool Enabled();
+protected:
     virtual int encodeName( const char *plaintextName, int length,
 	                    uint64_t *iv, char *encodedName ) const;
     virtual int decodeName( const char *encodedName, int length,
 	                    uint64_t *iv, char *plaintextName ) const;
-
-    // hack to help with static builds
-    static bool Enabled();
 private:
 };
 
