@@ -27,9 +27,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include <string.h>
+#include <cstring>
 
-#include <errno.h>
+#include <cerrno>
 
 using namespace std;
 
