@@ -19,11 +19,10 @@
 #define _StreamNameIO_incl_
 
 #include "NameIO.h"
-
-#include "Ptr.h"
+#include "CipherKey.h"
 
 class Cipher;
-typedef rel::OpaqueValue CipherKey;
+using boost::shared_ptr;
 
 class StreamNameIO : public NameIO
 {
@@ -31,7 +30,7 @@ public:
     static rel::Interface CurrentInterface();
 
     StreamNameIO( const rel::Interface &iface,
-	          const rel::Ptr<Cipher> &cipher, 
+	          const shared_ptr<Cipher> &cipher, 
 		  const CipherKey &key );
     virtual ~StreamNameIO();
 
@@ -40,16 +39,16 @@ public:
     virtual int maxEncodedNameLen( int plaintextNameLen ) const;
     virtual int maxDecodedNameLen( int encodedNameLen ) const;
 
+    // hack to help with static builds
+    static bool Enabled();
+protected:
     virtual int encodeName( const char *plaintextName, int length,
 	                    uint64_t *iv, char *encodedName ) const;
     virtual int decodeName( const char *encodedName, int length,
 	                    uint64_t *iv, char *plaintextName ) const;
-
-    // hack to help with static builds
-    static bool Enabled();
 private:
     int _interface;
-    rel::Ptr<Cipher> _cipher;
+    shared_ptr<Cipher> _cipher;
     CipherKey _key;
 };
 
