@@ -1,7 +1,7 @@
 #!/bin/sh
 
 echo Creating autoconf scripts...
-autoreconf -i
+sh ./reconfig.sh
 
 echo Configuring...
 ./configure
